# References

Some references about crystallographic definitions and conventions are
shown below. Though spglib may not follow them fully, it doesn't mean
spglib doesn't respect them, rather it is due to spglib-author's lack of
understanding the crystallography ashamedly.

## General materials

- [Bilbao Crystallographic Server](https://www.cryst.ehu.es/). The
  references of many useful papers are found in the
  [Articles page](https://www.cryst.ehu.es/wiki/index.php/Articles).
- [Online dictionary of crystallography](https://dictionary.iucr.org/Main_Page)

{cite:empty}`gen-ITA2016`
{cite:empty}`gen-muller2013symmetry`
{cite:empty}`gen-glazer2012space`

```{bibliography}
---
cited:
labelprefix: gen-
keyprefix: gen-
labelprefix: gen-
---
```

## Specific algorithms

{cite:empty}`algo-https://doi.org/10.1107/S0108767398010186`
{cite:empty}`algo-Grosse-Kunstleve:au0265`

```{bibliography}
---
cited:
labelprefix: algo-
keyprefix: algo-
labelprefix: algo-
---
```

## Setting and standardization

{cite:empty}`std-Hall:a19707`
{cite:empty}`std-parthe1984standardization`
{cite:empty}`std-PARTHE1993291`
{cite:empty}`std-parthe1985best`

```{bibliography}
---
cited:
labelprefix: std-
keyprefix: std-
labelprefix: std-
---
```

## Magnetic space group

{cite:empty}`msg-Gonzalez-Platas:tu5004`
{cite:empty}`msg-Gallego:ks5532`
{cite:empty}`msg-Campbell:ib5106`
{cite:empty}`msg-litvin2014magnetic`

```{bibliography}
---
cited:
labelprefix: msg-
keyprefix: msg-
labelprefix: msg-
---
```

## Mathematical treatment

{cite:empty}`math-Souvignier08`
{cite:empty}`math-Opgenorth:js0065`
{cite:empty}`math-Eick2005`
{cite:empty}`math-Eick:js0047`
{cite:empty}`math-10.2307/2322930`

```{bibliography}
---
cited:
labelprefix: math-
keyprefix: math-
labelprefix: math-
---
```
